@@ -27,5 +27,6 @@ class BootstrapRoles(object):
         user = self._get_role(Role.USER, RoleDataViewType.DOMAIN)
         sysadmin = self._get_role(Role.SYSADMIN, RoleDataViewType.MULTI_DOMAIN)
         admin = self._get_role(Role.ADMIN, RoleDataViewType.DOMAIN)
+        suporte = self._get_role(Role.SUPORTE, RoleDataViewType.MULTI_DOMAIN)
 
-        return [user, sysadmin, admin]
+        return [user, sysadmin, admin, suporte]
